/*
 * Copyright 2021 Paul Schaub.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package sop.util;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertThrows;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.nio.charset.StandardCharsets;

import org.junit.jupiter.api.Test;

public class ProxyOutputStreamTest {

    @Test
    public void replaceOutputStreamThrowsNPEForNull() {
        ProxyOutputStream proxy = new ProxyOutputStream();
        assertThrows(NullPointerException.class, () -> proxy.replaceOutputStream(null));
    }

    @Test
    public void testSwappingStreamPreservesWrittenBytes() throws IOException {
        byte[] firstSection = "Foo\nBar\n".getBytes(StandardCharsets.UTF_8);
        byte[] secondSection = "Baz\n".getBytes(StandardCharsets.UTF_8);

        ProxyOutputStream proxy = new ProxyOutputStream();
        proxy.write(firstSection);

        ByteArrayOutputStream swappedStream = new ByteArrayOutputStream();
        proxy.replaceOutputStream(swappedStream);

        proxy.write(secondSection);
        proxy.close();

        assertEquals("Foo\nBar\nBaz\n", swappedStream.toString());
    }
}
